Module scenes
pixels_
graphics_
lib
0.22.1
Module scenes
Module Items
Enums
Traits
Functions
Type Aliases
In crate pixels_
graphics_
lib
pixels_graphics_lib
Module
scenes
Enums

Scene
Update
Result
When a scene wants to add or remove a scene from the stack it should return
Push
or
Pop
from
Scene.update
Traits

PrePost
Scene
Scenes represent a mode/feature of a programs UI For example in an image editor you could have the main menu, editor, and save dialog as scenes and in an RPG you could have the field, battle and menu screens as scenes
Functions

empty_
pre_
post
run_
scenes
Convenience method for programs built using
Scene
s
Type Aliases

Scene
Switcher
Creates new scenes.