pub struct TextField { /* private fields */ }Implementations
Sourceimpl TextField
impl TextField
Sourcepub fn new<P: Into<Coord>>(
xy: P,
max_length: usize,
font: PixelFont,
size_limits: (Option<usize>, Option<usize>),
initial_content: &str,
filters: &[TextFilter],
style: &TextFieldStyle,
) -> Self
pub fn new<P: Into<Coord>>( xy: P, max_length: usize, font: PixelFont, size_limits: (Option<usize>, Option<usize>), initial_content: &str, filters: &[TextFilter], style: &TextFieldStyle, ) -> Self
UI element that allows text input Only supports characters in A-Z, a-z, 0-9, and some symbols a-z will be rendered as A-Z Does not support multiline
By default the width of the field is max_length * font width but this can be restricted/overridden using size_limits
Params
xy- Coord of top left cornemax_length- Max number of charstext_size- Size of text, effects width and heightsize_limits- Optional min and optional max width of field in pixels (including border + padding)filters- Filter allowed key, if empty then defaults to All
Sourceimpl TextField
impl TextField
pub fn clear(&mut self)
pub fn set_content(&mut self, text: &str)
pub fn content(&self) -> &str
pub fn is_focused(&self) -> bool
pub fn unfocus(&mut self)
pub fn focus(&mut self)
pub fn is_full(&self) -> bool
pub fn on_mouse_click(&mut self, down: Coord, up: Coord) -> bool
pub fn on_mouse_drag(&mut self, down: Coord, up: Coord)
pub fn on_key_press(&mut self, key: KeyCode, held_keys: &FxHashSet<KeyCode>)